==> huaweicloudsdkcsms-3.0.101-py2.py3-none-any.whl: huaweicloudsdkcsms/v1/model/update_secret_stage_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateSecretStageRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'secret_name': 'str',
        'stage_name': 'str',
        'body': 'UpdateSecretStageRequestBody'
    }

    attribute_map = {
        'secret_name': 'secret_name',
        'stage_name': 'stage_name',
        'body': 'body'
    }

    def __init__(self, secret_name=None, stage_name=None, body=None):
        """UpdateSecretStageRequest

        The model defined in huaweicloud sdk

        :param secret_name: 凭据名称。
        :type secret_name: str
        :param stage_name: 凭据版本状态的名称。
        :type stage_name: str
        :param body: Body of the UpdateSecretStageRequest
        :type body: :class:`huaweicloudsdkcsms.v1.UpdateSecretStageRequestBody`
        """
        
        

        self._secret_name = None
        self._stage_name = None
        self._body = None
        self.discriminator = None

        self.secret_name = secret_name
        self.stage_name = stage_name
        if body is not None:
            self.body = body

    @property
    def secret_name(self):
        """Gets the secret_name of this UpdateSecretStageRequest.

        凭据名称。

        :return: The secret_name of this UpdateSecretStageRequest.
        :rtype: str
        """
        return self._secret_name

    @secret_name.setter
    def secret_name(self, secret_name):
        """Sets the secret_name of this UpdateSecretStageRequest.

        凭据名称。

        :param secret_name: The secret_name of this UpdateSecretStageRequest.
        :type secret_name: str
        """
        self._secret_name = secret_name

    @property
    def stage_name(self):
        """Gets the stage_name of this UpdateSecretStageRequest.

        凭据版本状态的名称。

        :return: The stage_name of this UpdateSecretStageRequest.
        :rtype: str
        """
        return self._stage_name

    @stage_name.setter
    def stage_name(self, stage_name):
        """Sets the stage_name of this UpdateSecretStageRequest.

        凭据版本状态的名称。

        :param stage_name: The stage_name of this UpdateSecretStageRequest.
        :type stage_name: str
        """
        self._stage_name = stage_name

    @property
    def body(self):
        """Gets the body of this UpdateSecretStageRequest.


        :return: The body of this UpdateSecretStageRequest.
        :rtype: :class:`huaweicloudsdkcsms.v1.UpdateSecretStageRequestBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdateSecretStageRequest.


        :param body: The body of this UpdateSecretStageRequest.
        :type body: :class:`huaweicloudsdkcsms.v1.UpdateSecretStageRequestBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateSecretStageRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcsms-3.1.3-py2.py3-none-any.whl: huaweicloudsdkcsms/v1/model/update_secret_stage_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateSecretStageRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'secret_name': 'str',
        'stage_name': 'str',
        'body': 'UpdateSecretStageRequestBody'
    }

    attribute_map = {
        'secret_name': 'secret_name',
        'stage_name': 'stage_name',
        'body': 'body'
    }

    def __init__(self, secret_name=None, stage_name=None, body=None):
        """UpdateSecretStageRequest

        The model defined in huaweicloud sdk

        :param secret_name: 凭据名称。
        :type secret_name: str
        :param stage_name: 凭据版本状态的名称。满足 &#39;^[a-zA-Z0-9._-]{1,64}$&#39;
        :type stage_name: str
        :param body: Body of the UpdateSecretStageRequest
        :type body: :class:`huaweicloudsdkcsms.v1.UpdateSecretStageRequestBody`
        """
        
        

        self._secret_name = None
        self._stage_name = None
        self._body = None
        self.discriminator = None

        self.secret_name = secret_name
        self.stage_name = stage_name
        if body is not None:
            self.body = body

    @property
    def secret_name(self):
        """Gets the secret_name of this UpdateSecretStageRequest.

        凭据名称。

        :return: The secret_name of this UpdateSecretStageRequest.
        :rtype: str
        """
        return self._secret_name

    @secret_name.setter
    def secret_name(self, secret_name):
        """Sets the secret_name of this UpdateSecretStageRequest.

        凭据名称。

        :param secret_name: The secret_name of this UpdateSecretStageRequest.
        :type secret_name: str
        """
        self._secret_name = secret_name

    @property
    def stage_name(self):
        """Gets the stage_name of this UpdateSecretStageRequest.

        凭据版本状态的名称。满足 '^[a-zA-Z0-9._-]{1,64}$'

        :return: The stage_name of this UpdateSecretStageRequest.
        :rtype: str
        """
        return self._stage_name

    @stage_name.setter
    def stage_name(self, stage_name):
        """Sets the stage_name of this UpdateSecretStageRequest.

        凭据版本状态的名称。满足 '^[a-zA-Z0-9._-]{1,64}$'

        :param stage_name: The stage_name of this UpdateSecretStageRequest.
        :type stage_name: str
        """
        self._stage_name = stage_name

    @property
    def body(self):
        """Gets the body of this UpdateSecretStageRequest.


        :return: The body of this UpdateSecretStageRequest.
        :rtype: :class:`huaweicloudsdkcsms.v1.UpdateSecretStageRequestBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdateSecretStageRequest.


        :param body: The body of this UpdateSecretStageRequest.
        :type body: :class:`huaweicloudsdkcsms.v1.UpdateSecretStageRequestBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateSecretStageRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
